from __future__ import generators
import plus
import Arenas
import Hazards
import DSLHaz
import random

import math

class RingArena(Arenas.SuperArena):
    "The Beetleweight World Championship arena, ready for the best beetles in the world to face each other down. Can you take the beating?"
    name = "Beetle World Champs"
    preview = "beetleworldchamps/beetleworldchamps_preview.bmp"
    game_types = ['DEATHMATCH', 'BATTLE ROYAL', 'TEAM MATCH']

    def __init__(self):
        Arenas.SuperArena.__init__(self, "Arenas/beetleworldchamps/beetleworldchampsarena.gmf")
        #plus.Arena.__init__(self, "")
        plus.setBackColor(0,0,0)
        fmod = 0.015
        degrad = 0.01745
        self.AddStaticCamera("Garfie Cam", (13.8, 9, -17.04), (.367, -40*degrad), degrad*55)
        self.AddStaticCamera("Roof Cam", (0, 28.8, 0), (90*degrad, 90*degrad), degrad*37)
        self.AddStaticCamera("The Other Cam", (0, 14, -18), (40*degrad, 0), degrad*62)

        self.AddWatchCamera("Microgravity100 Cam", (17.8, 10, -18.04), (12, 20, 30*degrad, 20*degrad))
        self.AddWatchCamera("Roboteers Cam", (-16, 11, 1), (12, 20, 30*degrad, 20*degrad))
        self.AddWatchCamera("Crowd Cam", (32, 11, 1), (14, 22, 30*degrad, 30*degrad))
        self.AddWatchCamera("I wouldnt stand here", (4, 9, 17), (16, 24, 30*degrad, 40*degrad))
        self.AddWatchCamera("U shud stand here", (0, 14, -18), (16, 24, 30*degrad, 40*degrad))

        self.AddSound = plus.createSound("Sounds/rwleagueofchampsloop.wav", False, (0, 0, 0))
        plus.loopSound(self.AddSound)
                
        self.dropstart = 0
        self.droptimer = 0
        self.players = ()
		
    def __del__(self):
        if self.AddSound:
            plus.stopSound(self.AddSound)
            plus.removeSound(self.AddSound)
        Arenas.SuperArena.__del__(self)

    def AddShadowReceivers(self):
        pass
        
    def HazardsOn(self, on):
        if on:
            self.flame1 = DSLHaz.Flame((1.5, 5, 19), (0, 10, -5), (.5, 1, .5), 0.1)
            self.AddHazard(self.flame1)
            self.flame2 = DSLHaz.Flame((1.5, 5, -13.75), (0, 10, 5), (.5, 1, .5), 0.1)
            self.AddHazard(self.flame2)
	    self.flame3 = DSLHaz.Flame((1.5, 5, 19), (0, 10, -5), (.5, 1, .5), 0.1)
            self.AddHazard(self.flame3)
            self.flame4 = DSLHaz.Flame((1.5, 5, -13.75), (0, 10, 5), (.5, 1, .5), 0.1)
            self.AddHazard(self.flame4)

	self.AddCollisionLine((-17.75, 19.5), (21.25, 19.5))
        self.AddCollisionLine((21.25, 19.5), (21.25, -14.25))
        self.AddCollisionLine((21.25, -14.25), (-17.75, -14.25))
        self.AddCollisionLine((-17.75, -14.25), (-17.75, 19.5))

        return Arenas.SuperArena.HazardsOn(self, on)

    def Activate(self, on):    
        if on: self.players = plus.getPlayers()
        return Arenas.SuperArena.Activate(self, on)
        
    def Introduction(self):
        sounds = self.intro_sounds
        
        # set initial camera & fade from black
        plus.setCameraPosition(-18.3694,10.7193,-18.9036)
        plus.setCameraRotation(0.4012, 0.78539)
        plus.setCameraFOV(0.7753)
        plus.fadeFromBlack(.25)

        #start playing music loop
        self.intro_music = plus.createSound("Sounds/announcers/rwsilence.wav", False, (0,0,0))
        plus.setVolume(self.intro_music, 0, 0)
        plus.loopSound(self.intro_music)
        yield .25
        
        #load all sounds now to decrease lag later
        sounds['crowd'] = plus.createSound("Sounds/crowd/LoudCheer_Loop.wav", False, (0,0,0))
        
        arenaOpt = ("Sounds/announcers/rwringintro1.wav", "Sounds/announcers/rwringintro2.wav")
        sounds['arena'] = plus.createSound(random.choice(arenaOpt), False, (0,0,0))
        genericOpt = ("rwsilence.wav", "rwsilence.wav", "rwsilence.wav", "rwsilence.wav", "rwsilence.wav", "rwsilence.wav", "Irwsilence.wav", "rwsilence.wav")
        sounds['generic'] = plus.createSound("Sounds/announcers/"+random.choice(genericOpt), False, (0,0,0))
        botOpt = ("Bots_YouCanFeelTension.wav", "Bots_ColdChill.wav", "Bots_FansLoveTheseBots.wav", "Bots_SeeingInterestingDesigns.wav", "Bots_CrowdPoisedBotsArmed.wav")
        sounds['bots'] = plus.createSound("Sounds/announcers/"+random.choice(botOpt), False, (0,0,0))
        
        #intro cam, welcom comment
        plus.playSound(sounds['arena'])
        plus.fadeInToLoop(sounds['crowd'], -100, 800)
        plus.animateCamera((-18.3694,10.7193,-18.9036), (0.4012, 0.78539), 0.7753, (13.8, 9, -17.04), (0.4012, -0.78539), 0.7753, 0, 8)
        yield 2
        plus.fadeOutLoop(sounds['crowd'], 8000)
        yield 1
        
        #play a generic (or specific) secondary comment
        plus.playSound(sounds['generic'])
        yield 5

        pcount = len(self.players)
        if pcount>0: plus.playSound(sounds['bots'])
        delaytime = 6 - pcount
        
        if 0 in self.players:
            #bot 1 cam
            plus.animateCamera((10,20,0), (0.533,-1.57), 0.6, (10,20,0), (0.533,-1.57), 0.45, 0, delaytime)
            yield delaytime
            
        if 1 in self.players:
            #bot 2 cam
            plus.animateCamera((-10,20,0), (0.533,1.57), 0.6, (-10,20,0), (0.533,1.57), 0.45, 0, delaytime)
            yield delaytime
            
        if 2 in self.players:
            #bot 3 cam
            plus.animateCamera((0,20,-10), (0.533,0), 0.6, (0,20,-10), (0.533,0), 0.45, 0, delaytime)
            yield delaytime
            
        if 3 in self.players:
            #bot 4 cam
            plus.animateCamera((0,20,10), (0.533,3.14), 0.6, (0,20,10), (0.533,3.14), 0.45, 0, delaytime)
            yield delaytime
            
        #fade out music
        plus.fadeOutLoop(self.intro_music, 2000)
        yield 2
        
        # done
        yield 0
        
    def Tick(self):
	if self.bHazardsOn:
            self.flame1.FlameOn()
            self.flame2.FlameOn()
	    self.flame3.FlameOn()
            self.flame4.FlameOn()
            self.flame1.Tick()
            self.flame2.Tick()
	    self.flame3.Tick()
            self.flame4.Tick()

        for each in self.players:
            if plus.getLocation(each)[1] < 4.7:
                plus.eliminatePlayer(each)        
        return Arenas.SuperArena.Tick(self)

    def ZoneEvent(self, direction, id, robot, chassis):            
        return True

Arenas.register(RingArena)
